@@ -1,6 +1,6 @@
 package Package::DeprecationManager;
 BEGIN {
-  $Package::DeprecationManager::VERSION = '0.02';
+  $Package::DeprecationManager::VERSION = '0.03';
 }
 
 use strict;
@@ -21,7 +21,7 @@ sub import {
     my %registry;
 
     my $import = _build_import( \%registry );
-    my $warn = _build_warn( \%registry, $args{-deprecations} );
+    my $warn = _build_warn( \%registry, $args{-deprecations}, $args{-ignore} );
 
     my $caller = caller();
 
@@ -63,6 +63,9 @@ sub _build_import {
 sub _build_warn {
     my $registry      = shift;
     my $deprecated_at = shift;
+    my $ignore        = shift;
+
+    my %ignore = map { $_ => 1 } @{ $ignore || [] };
 
     my %warned;
 
@@ -71,6 +74,18 @@ sub _build_warn {
 
         my ( $package, undef, undef, $sub ) = caller(1);
 
+        my $skipped = 0;
+        if ( keys %ignore ) {
+            while ( defined $package && $ignore{$package} ) {
+                # We want to start two levels back, since we already looked
+                # one level back and found an internal package.
+                $package = caller($skipped++ + 2);
+                $skipped++;
+            }
+        }
+
+        $package = 'unknown package' unless defined $package;
+
         unless ( defined $args{feature} ) {
             $args{feature} = $sub;
         }
@@ -86,20 +101,21 @@ sub _build_warn {
 
         return if $warned{$package}{ $args{feature} };
 
+        my $msg;
         if ( defined $args{message} ) {
-            @_ = $args{message};
+            $msg = $args{message};
         }
         else {
-            my $msg = "$args{feature} has been deprecated";
+            $msg = "$args{feature} has been deprecated";
             $msg .= " since version $deprecated_at"
                 if defined $deprecated_at;
-
-            @_ = $msg;
         }
 
         $warned{$package}{ $args{feature} } = 1;
 
-        goto &Carp::cluck;
+        local $Carp::CarpLevel = $Carp::CarpLevel + 1 + $skipped;
+
+        Carp::cluck($msg);
     };
 }
 
@@ -117,7 +133,7 @@ Package::DeprecationManager - Manage deprecation warnings for your distribution
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -173,6 +189,12 @@ method as the feature name. This works for cases where the whole subroutine is
 deprecated. However, the feature names can be any string. This is useful if
 you don't want to deprecate an entire subroutine, just a certain usage.
 
+You can also provide an optional array reference in the C<-ignore>
+parameter. This is a list of package names to ignore when looking at the stack
+to figure out what code used the deprecated feature. This should be packages
+in your distribution that can appear on the call stack when a deprecated
+feature is used.
+
 As part of the import process, C<Package::DeprecationManager> will export two
 subroutines into its caller. It proves an C<import()> sub for the caller and a
 C<deprecated()> sub.
